from AccessControl import getSecurityManager
from five import grok
from zope import schema
from zope.schema.interfaces import IField
from zope.schema.interfaces import IPassword
from plone.directives import form
from plonetheme.nuplone import MessageFactory as _
from z3c.form.interfaces import IDataManager
from z3c.form.interfaces import NO_VALUE
from Products.PluggableAuthService.interfaces.authservice import IPropertiedUser
from Products.CMFCore.interfaces import ISiteRoot
from Products.CMFCore.utils import getToolByName

class ISettings(form.Schema):
    fullname = schema.TextLine(
            title=_("label_fullname", default=u"Full name"),
            required=True)

    email = schema.ASCIILine(
            title = _("label_email", default="Email address"),
            required=True)

    password = schema.Password(
            title = _("label_password", default=u"Password"),
            required = True)


class UserPropertyDataManager(grok.MultiAdapter):
    grok.adapts(IPropertiedUser, IField)
    grok.implements(IDataManager)

    def __init__(self, user, field):
        self.user=user
        self.field=field
        self.propname=field.__name__
        for sheet_id in user.listPropertysheets():
            sheet=user.getPropertysheet(sheet_id)
            if sheet.hasProperty(self.propname):
                self.propertysheet=sheet
                break
        else:
            self.propname=None


    def get(self):
        return self.propertysheet.getProperty(self.propname)

    def query(self, default=NO_VALUE):
        if self.propname is None:
            return default
        return self.propertysheet.getProperty(self.propname, NO_VALUE)

    def set(self, value):
        self.propertysheet.setProperty(self.user, self.propname, value)

    def canAccess(self):
        return self.propname is not None

    def canWrite(self):
        return self.propname is not None



class UserPasswordDataManager(grok.MultiAdapter):
    grok.adapts(IPropertiedUser, IPassword)
    grok.implements(IDataManager)

    def __init__(self, user, field):
        self.user=user
        self.field=field

    def get(self):
        raise AttributeError(self.field.__name__)

    def query(self, default=NO_VALUE):
        return default

    def set(self, value):
        mt=getToolByName(self.user, "portal_membership")
        mt.setPassword(value)

    def canAccess(self):
        return False

    def canWrite(self):
        return True


class Settings(form.SchemaEditForm):
    grok.context(ISiteRoot)
    grok.name("settings")

    schema = ISettings

    def getContent(self):
        return getSecurityManager().getUser()





from zope.i18nmessageid import MessageFactory as mf
MessageFactory = mf("nuplone")
del mf


def initialize(context):
    from AccessControl.Permissions import manage_users as ManageUsers
    from Products.PluggableAuthService.PluggableAuthService import registerMultiPlugin
    from euphorie.client import authentication

    registerMultiPlugin(authentication.EuphorieAccountPlugin.meta_type)
    context.registerClass(authentication.EuphorieAccountPlugin,
                          permission=ManageUsers,
                                constructors=
                                        (authentication.manage_addEuphorieAccountPlugin,
                                        authentication.addEuphorieAccountPlugin),
                                visibility=None)




import logging
import socket
from Acquisition import aq_inner
from zope import schema
from five import grok
from zope.i18n import translate
from plone.directives import form
from plonetheme.nuplone import MessageFactory as _
from Products.MailHost.MailHost import MailHostError
from Products.CMFCore.interfaces import ISiteRoot
from Products.CMFCore.utils import getToolByName
from Products.statusmessages.interfaces import IStatusMessage
from z3c.form.button import buttonAndHandler
from plonetheme.nuplone.z3cform.form import FieldWidgetFactory
from plonetheme.nuplone.utils import createEmailTo

log = logging.getLogger(__name__)

TextSpan7 = FieldWidgetFactory("z3c.form.browser.text.TextFieldWidget", klass="span-7")
TextLines4Rows = FieldWidgetFactory("z3c.form.browser.textlines.TextLinesFieldWidget", rows=4)


class IContact(form.Schema):
    name = schema.TextLine(
            title=_(u"label_your_name", default="Your name"),
            required=True)
    form.widget(name="plonetheme.nuplone.skin.contact.TextSpan7")

    email = schema.ASCIILine(
            title=_("label_email", default="Email address"),
            required=True)
    form.widget(email="plonetheme.nuplone.skin.contact.TextSpan7")

    subject = schema.TextLine(
            title=_(u"label_subject", default=u"Subject"),
            required=True)
    form.widget(subject="plonetheme.nuplone.skin.contact.TextSpan7")

    message = schema.Text(
            title=_("label_contact_text", default="Your message"),
            required=True)
    form.widget(message="plonetheme.nuplone.skin.contact.TextLines4Rows")



class ContactForm(form.SchemaForm):
    grok.context(ISiteRoot)
    grok.name("contact")
    grok.require("zope2.Public")

    ignoreContext = True
    schema = IContact
    label = _(u"header_contact", default="Contact")
    default_fieldset_label = None

    @buttonAndHandler(_("button_send", default="Send"), name="send")
    def handleSend(self, action):
        data, errors = self.extractData()
        if errors:
            self.status = self.formErrorsMessage
            return

        subject=_(u"contact_mail_subject", default=u"Contact request: ${subject}", mapping=data)
        subject=translate(subject, context=self.request)

        email=createEmailTo(data["name"], data["email"],
                            self.context.email_from_name,
                            self.context.email_from_address,
                            subject,
                            data["message"])
        mh=getToolByName(self.context, "MailHost")
        flash=IStatusMessage(self.request).addStatusMessage
        try:
            mh.send(email)
        except MailHostError, e:
            log.error("MailHost error sending contact form for %s: %s", data["email"], e)
            flash(_(u"error_contactmail", u"An error occured while processing your contact request. Please try again later."), "error")
            return
        except socket.error, e:
            log.error("Socket error sending contact form for %s: %s", data["email"], e[1])
            flash(_(u"error_contactmail", u"An error occured while processing your contact request. Please try again later."), "error")
            return

        flash(_(u"Message sent"), "success")
        self.request.response.redirect(aq_inner(self.context).absolute_url())




from Acquisition import aq_inner
from Acquisition import aq_parent
from zope.interface import Interface
from five import grok
from AccessControl.Permissions import copy_or_move
from AccessControl.Permissions import delete_objects
from plonetheme.nuplone.skin.interfaces import NuPloneSkin
from plonetheme.nuplone.utils import checkPermission
from plonetheme.nuplone.utils import getFactoriesInContext
from Products.CMFCore.interfaces import ISiteRoot
from OFS.interfaces import ICopyContainer
from OFS.interfaces import ICopySource


grok.templatedir("templates")


class Sitemenu(grok.View):
    grok.context(Interface)
    grok.name("sitemenu")
    grok.layer(NuPloneSkin)
    grok.template("sitemenu")

    @property
    def settings_url(self):
        return "%s/@@settings" % self.navroot_url

    def update(self):
        self.view_type=self.request.get("view_type", "view")

        context=aq_inner(self.context)
        parent=aq_parent(context)
        is_root=ISiteRoot.providedBy(context)
        is_copyable=not is_root and ICopySource.providedBy(context) and checkPermission(context, copy_or_move)
        self.can_delete=not is_root and checkPermission(parent, delete_objects)
        self.can_copy=is_copyable and context.cb_isCopyable()
        self.can_cut=is_copyable and self.can_delete and context.cb_isMoveable()
        self.can_paste=ICopyContainer.providedBy(context) and context.cb_dataValid()


    def factories(self):
        actions=getFactoriesInContext(self.context)
        actions.sort(key=lambda x: x.title)
        return actions



from setuptools import setup, find_packages
import os

version = "1.0a1"

setup(name="NuPlone",
      version=version,
      description="A new user interface for Plone",
      long_description=open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "changes.rst")).read(),
      classifiers=[
          "Development Status :: 2 - Pre-Alpha",
          "Environment :: Web Environment",
          "Framework :: Plone",
          "License :: OSI Approved :: GNU General Public License (GPL)",
          "Operating System :: OS Independent",
          "Programming Language :: JavaScript",
          "Programming Language :: Python",
        ],
      keywords="",
      author="Cornelis Kolbach and Wichert Akkerman",
      author_email="",
      url="http://packages.python.org/NuPlone",
      license="GPL",
      packages=find_packages(exclude=["ez_setup"]),
      namespace_packages=["plonetheme"],
      paster_plugins=["Babel"],
      message_extractors = {"plonetheme": [
            ("**.py",    "chameleon_python", None),
            ("**.pt"  ,  "chameleon_xml", None),
            ]},
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          "setuptools",
          "Plone >=4.0dev",
          "Zope2 >=2.12.5",
          "cmf.pt",
          "five.pt >= 1.2",
          "five.grok",
          "z3c.pt >=1.1.2",
          "plone.tiles",
          "plone.z3cform",
          "plone.app.z3cform >=0.4.10dev",
          "z3c.form [extra] >=2.3.4dev",
          "plone.i18n",
          "plone.autoform",
          "plone.supermodel",
          "plone.formwidget.namedfile >1.0b4",
          "z3c.appconfig",
          "p01.widget.password",
          "Products.statusmessages",
      ],
      entry_points="""
      """,
      )
